#[repr(C)]pub struct DeviceProgramKeyResponse {
pub slot: u8,
}Expand description
The wire type corresponding to DeviceProgramKeyResponse.
Fields
slot: u8Trait Implementations
Sourceimpl Clone for DeviceProgramKeyResponse
impl Clone for DeviceProgramKeyResponse
Sourcefn clone(&self) -> DeviceProgramKeyResponse
fn clone(&self) -> DeviceProgramKeyResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceProgramKeyResponse
impl Constrained for DeviceProgramKeyResponse
Sourceimpl Debug for DeviceProgramKeyResponse
impl Debug for DeviceProgramKeyResponse
Sourceimpl<___D> Decode<___D> for DeviceProgramKeyResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceProgramKeyResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceProgramKeyResponse, ___E> for &'a DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceProgramKeyResponse, ___E> for &'a DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceProgramKeyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceProgramKeyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceProgramKeyResponse, ___E> for DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceProgramKeyResponse, ___E> for DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceProgramKeyResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceProgramKeyResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceProgramKeyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceProgramKeyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceProgramKeyResponse, ___E> for DeviceProgramKeyResponse<T0>
impl<___E, T0> Encode<DeviceProgramKeyResponse, ___E> for DeviceProgramKeyResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceProgramKeyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceProgramKeyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
impl FromWire<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceProgramKeyResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceProgramKeyResponse, Self>
Sourcefn from_wire(wire: DeviceProgramKeyResponse) -> Self
fn from_wire(wire: DeviceProgramKeyResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
impl FromWireRef<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
Sourcefn from_wire_ref(wire: &DeviceProgramKeyResponse) -> Self
fn from_wire_ref(wire: &DeviceProgramKeyResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceProgramKeyResponse
impl IntoNatural for DeviceProgramKeyResponse
Sourcetype Natural = DeviceProgramKeyResponse
type Natural = DeviceProgramKeyResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceProgramKeyResponse
impl Wire for DeviceProgramKeyResponse
Sourcetype Narrowed<'de> = DeviceProgramKeyResponse
type Narrowed<'de> = DeviceProgramKeyResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.